All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH v4 net] net: sctp: Don't transition to PF state when transport has exhausted 'Path.Max.Retran
@ 2014-04-25 18:26 ` Karl Heiss
  0 siblings, 0 replies; 6+ messages in thread
From: Karl Heiss @ 2014-04-25 18:26 UTC (permalink / raw)
  To: netdev; +Cc: linux-sctp, davem, vyasevich, nhorman

Don't transition to the PF state on every strike after 'Path.Max.Retrans'.
Per draft-ietf-tsvwg-sctp-failover-03 Section 5.1.6:

   Additional (PMR - PFMR) consecutive timeouts on a PF destination
   confirm the path failure, upon which the destination transitions to the
   Inactive state.  As described in [RFC4960], the sender (i) SHOULD notify
   ULP about this state transition, and (ii) transmit heartbeats to the
   Inactive destination at a lower frequency as described in Section 8.3 of
   [RFC4960].

This also prevents sending SCTP_ADDR_UNREACHABLE to the user as the state
bounces between SCTP_INACTIVE and SCTP_PF for each subsequent strike.

Signed-off-by: Karl Heiss <kheiss@gmail.com>
---
Changes in v2:
  - Flesh out commit message

Changes in v3:
  - Compare transport state instead of pathmaxrxt

Changes in v4:
  - Simplify transport state comparison

 net/sctp/sm_sideeffect.c |    7 +++----
 1 files changed, 3 insertions(+), 4 deletions(-)

diff --git a/net/sctp/sm_sideeffect.c b/net/sctp/sm_sideeffect.c
index 5d6883f..f900f8e 100644
--- a/net/sctp/sm_sideeffect.c
+++ b/net/sctp/sm_sideeffect.c
@@ -496,11 +496,10 @@ static void sctp_do_8_2_transport_strike(sctp_cmd_seq_t *commands,
 
 	/* If the transport error count is greater than the pf_retrans
 	 * threshold, and less than pathmaxrtx, and if the current state
 	 * is not SCTP_UNCONFIRMED, then mark this transport as Partially
 	 * Failed, see SCTP Quick Failover Draft, section 5.1
 	 */
-	if ((transport->state != SCTP_PF) &&
-	   (transport->state != SCTP_UNCONFIRMED) &&
+	if ((transport->state = SCTP_ACTIVE) &&
 	   (asoc->pf_retrans < transport->pathmaxrxt) &&
 	   (transport->error_count > asoc->pf_retrans)) {
 
@@ -496,11 +496,10 @@ static void sctp_do_8_2_transport_strike(sctp_cmd_seq_t *commands,
 	/* If the transport error count is greater than the pf_retrans
 	 * threshold, and less than pathmaxrtx, and if the current state
-	 * is not SCTP_UNCONFIRMED, then mark this transport as Partially
-	 * Failed, see SCTP Quick Failover Draft, section 5.1
+	 * is SCTP_ACTIVE, then mark this transport as Partially Failed, 
+	 * see SCTP Quick Failover Draft, section 5.1
 	 */
-- 
1.7.1


^ permalink raw reply related	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2014-04-28  3:41 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2014-04-25 18:26 [PATCH v4 net] net: sctp: Don't transition to PF state when transport has exhausted 'Path.Max.Retran Karl Heiss
2014-04-25 18:26 ` [PATCH v4 net] net: sctp: Don't transition to PF state when transport has exhausted 'Path.Max.Retrans' Karl Heiss
2014-04-25 19:58 ` [PATCH v4 net] net: sctp: Don't transition to PF state when transport has exhausted 'Path.Max.Re Vlad Yasevich
2014-04-25 19:58   ` [PATCH v4 net] net: sctp: Don't transition to PF state when transport has exhausted 'Path.Max.Retrans' Vlad Yasevich
2014-04-28  3:41 ` [PATCH v4 net] net: sctp: Don't transition to PF state when transport has exhausted 'Path.Max.Re David Miller
2014-04-28  3:41   ` [PATCH v4 net] net: sctp: Don't transition to PF state when transport has exhausted 'Path.Max.Retrans' David Miller

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.